package VMOMI::ComplianceResultStatus;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
